#
# spec file for package python-zdaemon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define modname zdaemon
Name:           python-%{modname}
Version:        5.0
Release:        2.1
Summary:        Daemon process control library and tools
License:        ZPL-2.1
URL:            https://github.com/zopefoundation/zdaemon
Source:         https://files.pythonhosted.org/packages/source/z/zdaemon/%{modname}-%{version}.tar.gz
Patch0:         obs-timeout.patch
BuildRequires:  %{python_module ZConfig}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module manuel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module zc.customdoctests}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ZConfig
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
zdaemon is a Python package which provides APIs for managing
applications run as daemons. Its principal use to date has been to
manage the application server and storage server daemons for Zope / ZEO,
although it is not limited to running Python-based applications

%prep
%autosetup -p1 -n %{modname}-%{version}
# remove unwanted shebang
sed -i '1 { /^#!/ d }' src/zdaemon/tests/nokill.py
rm -rf src/zdaemon.egg-info

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/zdaemon

%check
pushd src
%pyunittest discover -v
popd

%post
%python_install_alternative zdaemon

%postun
%python_uninstall_alternative zdaemon

%files %{python_files}
%license LICENSE.txt
%doc README.rst CHANGES.rst
%python_alternative %{_bindir}/zdaemon
%{python_sitelib}/%{modname}
%{python_sitelib}/%{modname}-%{version}.dist-info

%changelog
* Wed Apr 10 2024 Dirk Müller <dmueller@suse.com>
- switch to modern python on sle15
* Tue Mar  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.0:
  * Drop support for Python 2.7, 3.5, 3.6.
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.4
  * Add support for Python 3.8, 3.9, 3.10, 3.11.
  * Drop support for Python 3.4.
  * Drop support for python setup.py test to run the tests. (#23)
  * Drop support for installing this package without having setuptools.
* Thu Apr 14 2022 pgajdos@suse.com
- do not require python-mock for build
* Fri Sep 24 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Patch out flaky tests that seldomly fails in obs:
  * obs-timeout.patch
* Tue Apr  9 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.3
  * Add support for Python 3.6 and 3.7.
  * Drop support for Python 3.3.
- Launch tests.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Jun 24 2017 aloisio@gmx.com
- Update to version 4.2.0:
  * Add support for Python 3.5.
  * Drop support for Python 2.6 and 3.2.
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.0:
  * Add --version command line option (fixes #4).
  * kill now accepts signal names, not just numbers (#11).
  * Restore logreopen as an alias for kill USR2 (removed in version
    3.0.0 due to lack of tests): #10.
  * Make logreopen also reopen the transcript log: #9.
  * Reopen event log on logreopen or reopen_transcript: #8.
  * Help message for reopen_transcript (#5).
  * Fix race condition where stop would be ignored if the daemon
    manager was waiting before respawning a crashed program. #13.
  * Partially fix delayed deadlock when the transcript file runs
    into a full disk (#1).
  * Fix test suite leaving stale processes behind (#7).
- additional changes from version 4.0.1:
  * Add support for PyPy. (PyPy3 is pending release of a fix for:
    https://bitbucket.org/pypy/pypy/issue/1946)
  * Add support for Python 3.4.
  * Add -t/--transcript command line option.
  * zdaemon can now be invoked as a module as in python -m zdaemon
- update project URL
- update source URL, tar.gz not available
- add new build dependency unzip
- declare BuildRoot
- declare python_sitelib for SLE11
- fix update-alternatives (post, postun)
- remove unwanted shebang of nokill.py
- update package documentation and add LICENSE.txt
* Sun Feb 16 2014 os-dev@jacraig.com
- Update to 4.0.0:
  * Note / test support for Python 3.2.
- Add requirement for python-ZConfig, see setup.py.
- Update source URL, .zip not available for this version.
* Fri Feb  7 2014 p.drouand@gmail.com
- Fix wrong implementation
* Fri Feb  7 2014 p.drouand@gmail.com
- Implement update-alternative
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Apr 16 2013 p.drouand@gmail.com
- Update to version 4.0.0a1
  + Added tox support and MANIFEST.in for proper releasing.
  + Added Python 3.3 support.
  + Drop Python 2.4 and 2.5 support.
- Added url as source; add BuildRequires: unzip
  Please see http://en.opensuse.org/SourceUrls
* Mon Jan 14 2013 p.drouand@gmail.com
-Update to 3.0.5 version:
  * Fixed: the status command didn't return a non-zero exit status when
  the program wasn't running. This made it impossible for other software
  (e.g. Puppet) to tell if a process was running.
- Update to 3.0.0 version:
  * Added an option, start-test-program to supply a test command to test
    whether the program managed by zdaemon is up and operational, rather
    than just running. When starting a program, the start command doesn't
    return until the test passes. You could, for example, use this to wait
    until a web server is actually accepting connections.
  * Added a start-timeout option to error if a program takes too long to start.
    This is especially useful in combination with the start-test-program option.
  * Added an option, stop-timeout, to control how long to wait for a graceful shutdown.
  * Previously, this was controlled by backoff-limit, which didn't make much sense.
  * Several undocumented, untested, and presumably unused features were removed.
* Thu Dec  8 2011 cfarrell@suse.com
- license update: ZPL-2.1
  Simplify to ZPL-2.1
* Wed Dec  7 2011 coolo@suse.com
- most is ZPL-2.1, only one test is ZPL-2.0
* Wed Nov 10 2010 coolo@novell.com
- fix file list
* Tue Jun 22 2010 hvogel@novell.com
- Get rid if buildroot removal in install
* Wed Jun  2 2010 hvogel@novell.com
- Initial Package, Version 2.0.4
